package com.tuoheng.task.controller;

import com.tuoheng.common.core.utils.JsonResult;
import com.tuoheng.task.entity.CloudBox;
import com.tuoheng.task.query.CloudBoxQuery;
import com.tuoheng.task.service.ICloudBoxService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

/**
 * 云盒表 前端控制器
 *
 * @author WangHaoran
 * @since 2022-06-28
 */
@RestController
@RequestMapping("/task-service/box")
public class CloudBoxController {

    @Autowired
    private ICloudBoxService cloudBoxService;

    /**
     * 获取云盒分页列表
     *
     * @param cloudBoxQuery 查询条件
     * @return
     */
    @GetMapping("/page")
    public JsonResult index(CloudBoxQuery cloudBoxQuery) {
        return cloudBoxService.getList(cloudBoxQuery);
    }

    /**
     * 添加云盒
     *
     * @param entity 实体对象
     * @return
     */
    @PostMapping("")
    public JsonResult add(@RequestBody CloudBox entity) {
        return cloudBoxService.add(entity);
    }

    /**
     * 更新云盒
     *
     * @param entity 实体对象
     * @return
     */
    @PutMapping("")
    public JsonResult edit(@RequestBody CloudBox entity) {
        return cloudBoxService.edit(entity);
    }

    /**
     * 删除云盒
     *
     * @param cloudBoxId 云盒ID
     * @return
     */
    @DeleteMapping("/{cloudBoxId}")
    public JsonResult delete(@PathVariable("cloudBoxId") String cloudBoxId) {
        return cloudBoxService.deleteById(cloudBoxId);
    }

    /**
     * 获取云盒列表
     *
     * @return
     */
    @GetMapping("/boxes")
    public JsonResult getCloudBoxList() {
        return cloudBoxService.getCloudBoxList();
    }
}
