package com.tuoheng.task.controller;

import com.tuoheng.common.core.utils.JsonResult;
import com.tuoheng.task.entity.Task;
import com.tuoheng.task.query.TaskQuery;
import com.tuoheng.task.service.ITaskService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

/**
 * 任务表 前端控制器
 *
 * @author WangHaoran
 * @since 2022-06-30
 */
@RestController
@RequestMapping("/task-service/task")
public class TaskController {

    @Autowired
    private ITaskService taskService;

    /**
     * 获取任务详情
     *
     * @param taskId 任务ID
     * @return
     */
    @GetMapping("/{taskId}")
    public JsonResult detail(@PathVariable("taskId") String taskId) {
        return taskService.detail(taskId);
    }

    /**
     * 获取任务分页列表
     *
     * @param taskQuery 查询条件
     * @return
     */
    @GetMapping("/page")
    public JsonResult index(TaskQuery taskQuery) {
        return taskService.getList(taskQuery);
    }

    /**
     * 添加任务
     *
     * @param entity 实体对象
     * @return
     */
    @PostMapping("")
    public JsonResult add(@RequestBody Task entity) {
        return taskService.add(entity);
    }

    /**
     * 更新任务
     *
     * @param entity 实体对象
     * @return
     */
    @PutMapping("")
    public JsonResult edit(@RequestBody Task entity) {
        return taskService.edit(entity);
    }

    /**
     * 删除任务
     *
     * @param taskId 任务ID
     * @return
     */
    @DeleteMapping("/{taskId}")
    public JsonResult delete(@PathVariable("taskId") String taskId) {
        return taskService.deleteById(taskId);
    }
}
