package com.tuoheng.task.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.tuoheng.common.core.common.BaseQuery;
import com.tuoheng.common.core.common.BaseServiceImpl;
import com.tuoheng.common.core.utils.JsonResult;
import com.tuoheng.common.core.utils.StringUtils;
import com.tuoheng.task.entity.CloudBox;
import com.tuoheng.task.mapper.CloudBoxMapper;
import com.tuoheng.task.query.CloudBoxQuery;
import com.tuoheng.task.service.ICloudBoxService;
import com.tuoheng.task.vo.CloudBoxVo;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;


/**
 * 云盒表 服务实现类
 *
 * @author WangHaoran
 * @since 2022-06-28
 */
@Service
public class CloudBoxServiceImpl extends BaseServiceImpl<CloudBoxMapper, CloudBox> implements ICloudBoxService {

    @Autowired
    private CloudBoxMapper cloudBoxMapper;

    /**
     * 获取云盒分页列表
     *
     * @param query 查询条件
     * @return
     */
    @Override
    public JsonResult getList(BaseQuery query) {
        CloudBoxQuery cloudBoxQuery = (CloudBoxQuery) query;

        // 分页查询条件
        IPage<CloudBox> page = new Page<>(cloudBoxQuery.getPage(), cloudBoxQuery.getLimit());
        IPage<CloudBox> pageData = cloudBoxMapper.selectPage(page, new LambdaQueryWrapper<CloudBox>()
                .like(StringUtils.isNotEmpty(cloudBoxQuery.getBoxName()), CloudBox::getBoxName, cloudBoxQuery.getBoxName())
                .eq(CloudBox::getMark, 1)
                .orderByDesc(CloudBox::getCreateTime));
        return JsonResult.success(pageData);
    }


    @Override
    public JsonResult getCloudBoxList() {
        List<CloudBox> cloudBoxList = cloudBoxMapper.selectList(new LambdaQueryWrapper<CloudBox>()
                .eq(CloudBox::getMark, 1)
                .orderByDesc(CloudBox::getCreateTime));

        List<CloudBoxVo> cloudBoxVoList = new ArrayList<>();
        cloudBoxList.forEach(item -> {
            CloudBoxVo cloudBoxVo = new CloudBoxVo();
            BeanUtils.copyProperties(item, cloudBoxVo);
            cloudBoxVoList.add(cloudBoxVo);
        });
        return JsonResult.success(cloudBoxVoList);
    }
}
