package com.tuoheng.task.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.tuoheng.common.core.common.BaseQuery;
import com.tuoheng.common.core.common.BaseServiceImpl;
import com.tuoheng.common.core.utils.JsonResult;
import com.tuoheng.common.core.utils.StringUtils;
import com.tuoheng.task.entity.CloudBox;
import com.tuoheng.task.entity.Equipment;
import com.tuoheng.task.mapper.EquipmentMapper;
import com.tuoheng.task.query.CloudBoxQuery;
import com.tuoheng.task.query.EquipmentQuery;
import com.tuoheng.task.service.IEquipmentService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;


/**
 * 飞行设备表 服务实现类
 *
 * @author WangHaoran
 * @since 2022-06-28
 */
@Service
public class EquipmentServiceImpl extends BaseServiceImpl<EquipmentMapper, Equipment> implements IEquipmentService {

    @Autowired
    private EquipmentMapper equipmentMapper;


    /**
     * 获取飞行设备分页列表
     *
     * @param query 查询条件
     * @return
     */
    @Override
    public JsonResult getList(BaseQuery query) {
        EquipmentQuery equipmentQuery = (EquipmentQuery) query;

        // 分页查询条件
        IPage<Equipment> page = new Page<>(equipmentQuery.getPage(), equipmentQuery.getLimit());
        IPage<Equipment> pageData = equipmentMapper.selectPage(page, new LambdaQueryWrapper<Equipment>()
                .like(StringUtils.isNotEmpty(equipmentQuery.getName()), Equipment::getName, equipmentQuery.getName())
                .like(StringUtils.isNotEmpty(equipmentQuery.getManufacturer()), Equipment::getManufacturer, equipmentQuery.getManufacturer())
                .eq(equipmentQuery.getPowerType() != null, Equipment::getPowerType, equipmentQuery.getPowerType())
                .eq(Equipment::getMark, 1));
        return JsonResult.success(pageData);
    }

}
