package com.tuoheng.task.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.tuoheng.common.core.common.BaseQuery;
import com.tuoheng.common.core.common.BaseServiceImpl;
import com.tuoheng.common.core.utils.JsonResult;
import com.tuoheng.common.core.utils.StringUtils;
import com.tuoheng.task.api.fegin.ICityService;
import com.tuoheng.task.api.fegin.vo.CityVo;
import com.tuoheng.task.entity.Stream;
import com.tuoheng.task.mapper.StreamMapper;
import com.tuoheng.task.query.StreamQuery;
import com.tuoheng.task.service.IStreamService;
import com.tuoheng.task.vo.StreamInfoVo;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;


/**
 * 河道表 服务实现类
 *
 * @author WangHaoran
 * @since 2022-06-28
 */
@Service
public class StreamServiceImpl extends BaseServiceImpl<StreamMapper, Stream> implements IStreamService {

    @Autowired
    private StreamMapper streamMapper;

    @Autowired
    private ICityService cityService;

    /**
     * 获取河道分页列表
     *
     * @param query 查询条件
     * @return
     */
    @Override
    public JsonResult getList(BaseQuery query) {
        StreamQuery streamQuery = (StreamQuery) query;

        // 分页查询条件
        IPage<Stream> page = new Page<>(streamQuery.getPage(), streamQuery.getLimit());
        IPage<Stream> pageData = streamMapper.selectPage(page, new LambdaQueryWrapper<Stream>()
                .like(StringUtils.isNotEmpty(streamQuery.getName()), Stream::getName, streamQuery.getName())
                .eq(StringUtils.isNotEmpty(streamQuery.getProvinceCode()), Stream::getProvinceCode, streamQuery.getProvinceCode())
                .eq(StringUtils.isNotEmpty(streamQuery.getCityCode()), Stream::getCityCode, streamQuery.getCityCode())
                .eq(StringUtils.isNotEmpty(streamQuery.getDistrictCode()), Stream::getDistrictCode, streamQuery.getDistrictCode())
                .eq(StringUtils.isNotEmpty(streamQuery.getStreetCode()), Stream::getStreetCode, streamQuery.getStreetCode())
                .eq(StringUtils.isNotEmpty(streamQuery.getAdminId()), Stream::getAdminId, streamQuery.getAdminId())
                .eq(Stream::getMark, 1));

        pageData.convert(x -> {
            StreamInfoVo streamInfoVo = new StreamInfoVo();
            BeanUtils.copyProperties(x, streamInfoVo);
            CityVo cityVo = null;
            if (StringUtils.isNotEmpty(x.getStreetCode())) {
                // 最后一级到街道
                cityVo = cityService.getCityInfoByCode(x.getStreetCode()).getData();
            }else if (StringUtils.isEmpty(x.getStreetCode()) && StringUtils.isNotEmpty(x.getDistrictCode())) {
                // 最后一级到区
                cityVo = cityService.getCityInfoByCode(x.getDistrictCode()).getData();
            }else if (StringUtils.isEmpty(x.getDistrictCode()) && StringUtils.isNotEmpty(x.getCityCode())) {
                // 最后一级到市
                cityVo = cityService.getCityInfoByCode(x.getCityCode()).getData();
            }else if (StringUtils.isEmpty(x.getCityCode()) && StringUtils.isNotEmpty(x.getProvinceCode())) {
                // 最后一级到省
                cityVo = cityService.getCityInfoByCode(x.getProvinceCode()).getData();
            }
            if(cityVo != null){
                streamInfoVo.setCityArea(cityVo.getCityArea());
                streamInfoVo.setProvinceName(cityVo.getProvinceName());
                streamInfoVo.setCityName(cityVo.getCityName());
                streamInfoVo.setDistrictName(cityVo.getDistrictName());
                streamInfoVo.setStreetName(cityVo.getStreetName());
            }
            return streamInfoVo;
        });
        return JsonResult.success(pageData);
    }


}
